@@ -70,6 +70,10 @@ bool read_ed25519_key(uint8_t *in, size_t in_len, uint8_t *out,
   uint8_t decoded[128];
   size_t decoded_len = sizeof(decoded);
 
+  if (in_len < (28 + 26)) {
+    return false;
+  }
+
   if (memcmp(in, PEM_private_header, 28) != 0 ||
       memcmp(in + in_len - 26, PEM_private_trailer, 25) != 0) {
     return false;
@@ -704,7 +708,9 @@ bool write_file(const uint8_t *buf, size_t buf_len, FILE *fp, format_t format) {
   } while (!feof(fp) && !ferror(fp) && length > 0);
 
   if (fp == stdout || fp == stderr) {
-    fprintf(fp, "\n");
+    if ( format != _binary ) {
+      fprintf(fp, "\n");
+    }
   }
 
   if (b64 != NULL) {
